@@ -64,3 +64,11 @@ def until_none(items: Iterable[Optional[_T]]) -> Iterable[_T]:
         if item is None:
             break
         yield item
+
+
+def infinite_gen(function: Callable[[_T], _T], init: _T):
+    yield init
+    current = init
+    while True:
+        current = function(current)
+        yield current
